summaryrefslogtreecommitdiffstats
path: root/kipi-plugins/htmlexport/abstractthemeparameter.h
diff options
context:
space:
mode:
Diffstat (limited to 'kipi-plugins/htmlexport/abstractthemeparameter.h')
-rw-r--r--kipi-plugins/htmlexport/abstractthemeparameter.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/kipi-plugins/htmlexport/abstractthemeparameter.h b/kipi-plugins/htmlexport/abstractthemeparameter.h
index 7c6393a..5127232 100644
--- a/kipi-plugins/htmlexport/abstractthemeparameter.h
+++ b/kipi-plugins/htmlexport/abstractthemeparameter.h
@@ -21,9 +21,9 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
#ifndef ABSTRACTTHEMEPARAMETER_H
#define ABSTRACTTHEMEPARAMETER_H
-class QCString;
-class QString;
-class QWidget;
+class TQCString;
+class TQString;
+class TQWidget;
class KConfigBase;
namespace KIPIHTMLExport {
@@ -42,25 +42,25 @@ public:
* Reads theme parameters from configFile. Initializes the internalName,
* name and defaultValue fields.
*/
- virtual void init(const QCString& internalName, const KConfigBase* configFile);
+ virtual void init(const TQCString& internalName, const KConfigBase* configFile);
- QCString internalName() const;
+ TQCString internalName() const;
- QString name() const;
+ TQString name() const;
- QString defaultValue() const;
+ TQString defaultValue() const;
/**
* This method should return a QWidget representing the parameter,
* initialized with value.
*/
- virtual QWidget* createWidget(QWidget* parent, const QString& value) const = 0;
+ virtual TQWidget* createWidget(TQWidget* tqparent, const TQString& value) const = 0;
/**
* The opposite of createWidget: given a widget previously created with
* createWidget, this method returns the current widget value.
*/
- virtual QString valueFromWidget(QWidget*) const = 0;
+ virtual TQString valueFromWidget(TQWidget*) const = 0;
private:
class Private;
@@ -42,25 +42,25 @@ public:
/**
- * This method should return a QWidget representing the parameter,
+ * This method should return a TQWidget representing the parameter,
* initialized with value.
*/